@@ -13,6 +13,7 @@ class MainWindow;
 }
 namespace KTextEditor
 {
+class Document;
 class View;
 }
 
@@ -31,8 +32,6 @@ namespace Ui
 class ToolView;
 }
 
-enum class ToolViewFocus { OutputTab = 0, StatusTab };
-
 /**
  * Menu action that displays all KateExternalTool in a submenu.
  * Enables/disables the tool actions whenever the view changes, depending on the mimetype.
@@ -41,7 +40,10 @@ class KateExternalToolsMenuAction : public KActionMenu
 {
     Q_OBJECT
 public:
-    KateExternalToolsMenuAction(const QString &text, KActionCollection *collection, KateExternalToolsPlugin *plugin, class KTextEditor::MainWindow *mw = nullptr);
+    KateExternalToolsMenuAction(const QString &text,
+                                KActionCollection *collection,
+                                KateExternalToolsPlugin *plugin,
+                                class KTextEditor::MainWindow *mw = nullptr);
     virtual ~KateExternalToolsMenuAction();
 
     /**
@@ -57,10 +59,15 @@ public:
 private Q_SLOTS:
     /**
      * Called whenever the current view changed.
-     * Required to enable/disable the tools that depend on specific mimetypes.
+     * Calls updateActionState() for the corresponding document.
      */
     void slotViewChanged(KTextEditor::View *view);
 
+    /**
+     * Required to enable/disable the tools that depend on specific mimetypes.
+     */
+    void updateActionState(KTextEditor::Document *activeDoc);
+
     /**
      * Triggered via Tools > External Tools > Configure...
      */
@@ -70,6 +77,7 @@ private:
     KateExternalToolsPlugin *m_plugin;
     KTextEditor::MainWindow *m_mainwindow; // for the actions to access view/doc managers
     KActionCollection *m_actionCollection;
+    QMetaObject::Connection m_docUrlChangedConnection;
 };
 
 class KateExternalToolsPluginView : public QObject, public KXMLGUIClient
@@ -106,19 +114,13 @@ public Q_SLOTS:
     /**
      * Shows the tool view. The toolview will be created, if not yet existing.
      */
-    void showToolView(ToolViewFocus tab);
+    void showToolView();
 
     /**
      * Clears the toolview data. If no toolview is around, nothing happens.
      */
     void clearToolView();
 
-    /**
-     * Shows the External Tools toolview and points the error message along with
-     * some more info about the tool.
-     */
-    void addToolStatus(const QString &message);
-
     /**
      * Sets the output data to data;
      */
@@ -134,6 +136,14 @@ public Q_SLOTS:
      */
     void handleEsc(QEvent *event);
 
+Q_SIGNALS:
+    /**
+     * Signal for outgoing message, the host application will handle them!
+     * Will only be handled inside the main windows of this plugin view.
+     * @param message outgoing message we send to the host application
+     */
+    void message(const QVariantMap &message);
+
 private:
     KateExternalToolsPlugin *m_plugin;
     KTextEditor::MainWindow *m_mainWindow;
@@ -141,7 +151,6 @@ private:
     QWidget *m_toolView = nullptr;
     Ui::ToolView *m_ui = nullptr;
     QTextDocument *m_outputDoc = nullptr;
-    QTextDocument *m_statusDoc = nullptr;
 };
 
 #endif // KTEXTEDITOR_EXTERNALTOOLS_H
