@@ -124,7 +124,7 @@ void ConfigView::registerActions(KActionCollection *actionCollection)
 {
     m_targetSelectAction = actionCollection->add<KSelectAction>(QStringLiteral("targets"));
     m_targetSelectAction->setText(i18n("Targets"));
-    connect(m_targetSelectAction, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &ConfigView::slotTargetSelected);
+    connect(m_targetSelectAction, &KSelectAction::indexTriggered, this, &ConfigView::slotTargetSelected);
 }
 
 void ConfigView::readConfig(const KConfigGroup &group)
@@ -140,8 +140,9 @@ void ConfigView::readConfig(const KConfigGroup &group)
 
     for (int i = 0; i < targetCount; i++) {
         targetConfStrs = group.readEntry(targetKey.arg(i), QStringList());
-        if (targetConfStrs.count() == 0)
+        if (targetConfStrs.count() == 0) {
             continue;
+        }
 
         if ((version == 1) && (targetConfStrs.count() == 3)) {
             // valid old style config, translate it now; note the
@@ -177,8 +178,9 @@ void ConfigView::readConfig(const KConfigGroup &group)
                 if (i > 0) {
                     // copy the firsts and change the arguments
                     targetConfStrs[0] = targetName.arg(targetConfStrs[0]).arg(i + 1);
-                    if (targetConfStrs.count() > 3)
+                    if (targetConfStrs.count() > 3) {
                         targetConfStrs[3] = argStr;
+                    }
                     m_targetCombo->addItem(targetConfStrs[0], targetConfStrs);
                 }
             }
@@ -195,8 +197,9 @@ void ConfigView::readConfig(const KConfigGroup &group)
     }
     m_targetSelectAction->setItems(targetNames);
 
-    if (lastTarget < 0 || lastTarget >= m_targetCombo->count())
+    if (lastTarget < 0 || lastTarget >= m_targetCombo->count()) {
         lastTarget = 0;
+    }
     m_targetCombo->setCurrentIndex(lastTarget);
 
     m_takeFocus->setChecked(group.readEntry("alwaysFocusOnInput", false));
@@ -272,10 +275,8 @@ bool ConfigView::showIOTab() const
 void ConfigView::slotTargetEdited(const QString &newText)
 {
     QString newComboText(newText);
-    for (int i=0; i<m_targetCombo->count(); ++i) {
-        if (i != m_targetCombo->currentIndex() &&
-            m_targetCombo->itemText(i) == newComboText)
-        {
+    for (int i = 0; i < m_targetCombo->count(); ++i) {
+        if (i != m_targetCombo->currentIndex() && m_targetCombo->itemText(i) == newComboText) {
             newComboText = newComboText + QStringLiteral(" 2");
         }
     }
@@ -428,16 +429,18 @@ void ConfigView::setAdvancedOptions()
     QStringList tmp = m_targetCombo->itemData(m_targetCombo->currentIndex()).toStringList();
 
     // make sure we have enough strings;
-    while (tmp.count() < CustomStartIndex)
+    while (tmp.count() < CustomStartIndex) {
         tmp << QString();
+    }
 
     if (tmp[GDBIndex].isEmpty()) {
         tmp[GDBIndex] = QStringLiteral("gdb");
     }
 
     // Remove the strings that are not part of the advanced settings
-    for (int i = 0; i < GDBIndex; i++)
+    for (int i = 0; i < GDBIndex; i++) {
         tmp.takeFirst();
+    }
 
     m_advanced->setConfigs(tmp);
 }
@@ -448,17 +451,19 @@ void ConfigView::slotAdvancedClicked()
 
     QStringList newList = m_targetCombo->itemData(m_targetCombo->currentIndex()).toStringList();
     // make sure we have enough strings;
-    while (newList.count() < GDBIndex)
+    while (newList.count() < GDBIndex) {
         newList << QString();
+    }
     // Remove old advanced settings
-    while (newList.count() > GDBIndex)
+    while (newList.count() > GDBIndex) {
         newList.takeLast();
+    }
 
     if (m_advanced->exec() == QDialog::Accepted) {
         // save the new values
         newList << m_advanced->configs();
         m_targetCombo->setItemData(m_targetCombo->currentIndex(), newList);
-        emit configChanged();
+        Q_EMIT configChanged();
     }
 }
 
@@ -500,8 +505,9 @@ void ConfigView::saveCurrentToIndex(int index)
 
     QStringList tmp = m_targetCombo->itemData(index).toStringList();
     // make sure we have enough strings. The custom init strings are set in slotAdvancedClicked().
-    while (tmp.count() < CustomStartIndex)
+    while (tmp.count() < CustomStartIndex) {
         tmp << QString();
+    }
 
     tmp[NameIndex] = m_targetCombo->itemText(index);
     tmp[ExecIndex] = m_executable->text();
@@ -519,8 +525,9 @@ void ConfigView::loadFromIndex(int index)
 
     QStringList tmp = m_targetCombo->itemData(index).toStringList();
     // make sure we have enough strings. The custom init strings are set in slotAdvancedClicked().
-    while (tmp.count() < CustomStartIndex)
+    while (tmp.count() < CustomStartIndex) {
         tmp << QString();
+    }
 
     m_executable->setText(tmp[ExecIndex]);
     m_workingDirectory->setText(tmp[WorkDirIndex]);
