@@ -15,7 +15,6 @@
 
 #include <KConfigGroup>
 #include <KDesktopFile>
-#include <KDirWatch>
 #include <KIO/CopyJob>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -29,7 +28,6 @@
 #include <QDBusReply>
 #include <QDir>
 #include <QInputDialog>
-#include <QScopedPointer>
 #include <QUrl>
 
 #ifndef Q_OS_WIN
@@ -50,18 +48,13 @@ KateSessionManager::KateSessionManager(QObject *parent, const QString &sessionsD
     // create dir if needed
     QDir().mkpath(m_sessionsDir);
 
-    m_dirWatch = new KDirWatch(this);
+    m_dirWatch = std::make_unique<KDirWatch>(this);
     m_dirWatch->addDir(m_sessionsDir);
-    connect(m_dirWatch, &KDirWatch::dirty, this, &KateSessionManager::updateSessionList);
+    connect(m_dirWatch.get(), &KDirWatch::dirty, this, &KateSessionManager::updateSessionList);
 
     updateSessionList();
 }
 
-KateSessionManager::~KateSessionManager()
-{
-    delete m_dirWatch;
-}
-
 void KateSessionManager::updateSessionList()
 {
     QStringList list;
@@ -115,7 +108,7 @@ bool KateSessionManager::activateSession(KateSession::Ptr session, const bool cl
             return false;
         }
 
-        if (instances.contains(session->name())) {
+        if (instances.find(session->name()) != instances.end()) {
             if (KMessageBox::questionYesNo(nullptr,
                                            i18n("Session '%1' is already opened in another kate instance, change there instead of reopening?", session->name()),
                                            QString(),
@@ -123,13 +116,10 @@ bool KateSessionManager::activateSession(KateSession::Ptr session, const bool cl
                                            KStandardGuiItem::no(),
                                            QStringLiteral("katesessionmanager_switch_instance"))
                 == KMessageBox::Yes) {
-                instances[session->name()]->dbus_if->call(QStringLiteral("activate"));
-                cleanupRunningKateAppInstanceMap(&instances);
+                instances[session->name()].dbus_if->call(QStringLiteral("activate"));
                 return false;
             }
         }
-
-        cleanupRunningKateAppInstanceMap(&instances);
     }
     // try to close and save last session
     if (closeAndSaveLast) {
@@ -588,7 +578,7 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
         return;
     }
 
-    QScopedPointer<KDesktopFile> df(new KDesktopFile(service->entryPath()));
+    std::unique_ptr<KDesktopFile> df(new KDesktopFile(service->entryPath()));
 
     QStringList newActions = df->readActions();
 
